rcparams = {
    "svg.fonttype": "none",
    "pdf.fonttype": 42,
    "savefig.transparent": True,
    "figure.figsize": (4, 4),
    "axes.titlesize": 15,
    "axes.titleweight": 500,
    "axes.titlepad": 8.0,
    "axes.labelsize": 14,
    "axes.labelweight": 500,
    "axes.linewidth": 1.2,
    "axes.labelpad": 6.0,
    "font.size": 11,
    "font.family": "sans-serif",
    "font.sans-serif": [
        "Helvetica",
        "Computer Modern Sans Serif",
        "DejaVU Sans",
    ],
    "font.weight": 500,
    "xtick.labelsize": 12,
    "xtick.minor.size": 1.375,
    "xtick.major.size": 2.75,
    "xtick.major.pad": 2,
    "xtick.minor.pad": 2,
    "ytick.labelsize": 12,
    "ytick.minor.size": 1.375,
    "ytick.major.size": 2.75,
    "ytick.major.pad": 2,
    "ytick.minor.pad": 2,
    "legend.fontsize": 12,
    "legend.handlelength": 1.4,
    "legend.numpoints": 1,
    "legend.scatterpoints": 3,
    "legend.frameon": False,
    "lines.linewidth": 1.7,
}
